/*
 *  Copyright 2001-2006 Stephen Colebourne
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.joda.time;

import java.util.TimeZone;

/**
 * Entry point for all tests in this package.
 * 
 * @version $Revision: 1057 $ $Date: 2006-04-01 15:33:41 +0100 (Sat, 01 Apr
 * 2006) $
 * 
 * @author Stephen Colebourne
 */
public class TempTest {

    public static void main(String args[]) {
        
        DateTime a = new DateTime(1989, 7, 25, 0, 0, 0, 0);
        DateTime b = new DateTime(1994, 7, 18, 0, 0, 0, 0);
        System.out.println(new Period(a, b));

        // new TempTest().testZone();
    }

    public void testZone() {
        DateTimeZone zone = DateTimeZone.forID("America/Sao_Paulo");
        YearMonthDay baseDate = new YearMonthDay(2006, 10, 15);
        try {
            baseDate.toDateMidnight(zone);
        } catch (IllegalArgumentException ex) {
            DateTime dm = baseDate.plusDays(1).toDateTimeAtMidnight(zone);
            long adjustedMillis = zone.previousTransition(dm.getMillis()) + 1;
            dm = new DateTime(adjustedMillis, zone);
            System.out.println(dm);
        }
        DateTime dt = baseDate.toDateTime(new TimeOfDay(12, 0), zone);
        System.out.println(dt);
        dt = dt.dayOfYear().roundFloorCopy();
        System.out.println(dt);
    }
    
    public void testPlusMonths() {
        Object[] allTimeZones = DateTimeZone.getAvailableIDs().toArray();
        //System.out.println("OK state;Timezone Alias;Timezone name");
        for (int i = 0; i < allTimeZones.length; i++) {
            plusMonths((String) allTimeZones[i], 1800);
        }
//        plusMonths("Europe/London", 1600);
    }

    private void plusMonths(String tzId, int year) {

        setTimezone(tzId);

        DateTime startDate;
        boolean ok = true;
        for (int hr = 0; hr < 24; hr++) {
            try {
                startDate = new DateTime(year, 1, 1, hr, 0, 0, 0);
            } catch (IllegalArgumentException e) {
                // DateTime does not exist, due to timezone offset transition
                continue;
            }
            startDate = new DateTime("1911-12-01T00:00:00.000-00:16:08");
            if (plusMonthsWith(startDate) == false) {
                ok = false;
                break;
            }
        }

        if (!ok) {
            System.out.println("NOK;" + DateTimeZone.getDefault().getID() + ";" + tzId);
        } else {
            //System.out.println("OK;" + DateTimeZone.getDefault().getID() + ";" + tzId);
        }
    }

    private boolean plusMonthsWith(DateTime startDate) {

        int latestMonth;
        int expectedMonth;
        DateTime lastDT;
        DateTime dt = startDate.toDateTime();
        boolean ok = true;
        for (int i = 0; i < 10000; i++) {
            latestMonth = dt.getMonthOfYear();
            lastDT = dt;
            dt = dt.plusMonths(1);
            if (latestMonth == 12) {
                expectedMonth = 1;
            } else {
                expectedMonth = latestMonth + 1;
            }
            // assertEquals(expectedMonth, dt.getMonthOfYear());
            if (expectedMonth != dt.getMonthOfYear()) {
                System.out.println("ExpectedMonth=" + expectedMonth);
                System.out.println("  ActualMonth=" + dt.getMonthOfYear());
                System.out.println("      LastDT=" + lastDT);
                System.out.println("    ActualDT=" + dt);
                System.out.println("         Zone=" + new DateTime(DateTimeZone.getDefault().previousTransition(dt.getMillis() - 1) - 1));
                System.out.println("         Zone=" + new DateTime(DateTimeZone.getDefault().previousTransition(dt.getMillis()) - 1));
                System.out.println("         Zone=" + new DateTime(DateTimeZone.getDefault().nextTransition(dt.getMillis()) + 1));
                System.out.println("         Zone=" + new DateTime(DateTimeZone.getDefault().nextTransition(dt.getMillis() + 1) + 1));
                if (!ok) {
                    System.exit(0);
                }
                ok = false;
                //break;
            }
        }
        //System.out.println("         EndDT=" + dt);

        return ok;
    }

    private void setTimezone(String id) {
        DateTimeZone.setDefault(DateTimeZone.forID(id));
        TimeZone.setDefault(TimeZone.getTimeZone(DateTimeZone.getDefault().getID()));
    }

}
